pub enum RmuxCommandKind {
Request(Request),
NewSession(NewSessionSpec),
AttachSession(AttachSessionSpec),
SplitWindow(SplitSpec),
RefreshClient(RefreshClientSpec),
}Expand description
A detached command payload accepted by the SDK.
Variants
Request(Request)
A protocol request supplied directly by the caller.
NewSession(NewSessionSpec)
A new-session SDK spec.
AttachSession(AttachSessionSpec)
An attach-session SDK spec.
SplitWindow(SplitSpec)
A split-window SDK spec.
RefreshClient(RefreshClientSpec)
A refresh-client SDK spec.
Implementations
Sourceimpl RmuxCommandKind
impl RmuxCommandKind
Sourcepub fn command_name(&self) -> &'static str
pub fn command_name(&self) -> &'static str
Returns the stable public command name for this value object.
Sourcepub fn into_request(self) -> Request
pub fn into_request(self) -> Request
Converts this value object into the corresponding protocol request.