pub struct RmuxCommand {
pub endpoint: RmuxEndpoint,
pub command: RmuxCommandKind,
}Expand description
Endpoint-scoped SDK command DTO.
Fields
endpoint: RmuxEndpointEndpoint selector associated with this command.
command: RmuxCommandKindInert command payload.
Implementations
Sourceimpl RmuxCommand
impl RmuxCommand
Sourcepub fn new(command: impl Into<RmuxCommandKind>) -> Self
pub fn new(command: impl Into<RmuxCommandKind>) -> Self
Creates a command using the platform default endpoint selector.
Sourcepub fn with_endpoint(
endpoint: RmuxEndpoint,
command: impl Into<RmuxCommandKind>,
) -> Self
pub fn with_endpoint( endpoint: RmuxEndpoint, command: impl Into<RmuxCommandKind>, ) -> Self
Creates a command using an explicit endpoint selector.
Sourcepub fn command_name(&self) -> &'static str
pub fn command_name(&self) -> &'static str
Returns the stable public command name for the command payload.
Sourcepub fn into_request(self) -> Request
pub fn into_request(self) -> Request
Converts the command payload into its protocol request.