#[non_exhaustive]pub enum KeyConversionError {
UnsupportedKeyCode(&'static str),
UnsupportedModifier(&'static str),
NonPressEvent,
}Expand description
Errors produced when converting a foreign key event into the SDK vocabulary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedKeyCode(&'static str)
The foreign event used a key code variant that the SDK does not model (for example a media key when no enhancement flags were negotiated).
UnsupportedModifier(&'static str)
The foreign event used modifier bits the SDK does not model.
NonPressEvent
The foreign event reported a key release/repeat the SDK ignores.