SessionLayoutBuilder

Struct SessionLayoutBuilder 

pub struct SessionLayoutBuilder<'a> { /* private fields */ }
Entry point returned by Session::layout.

Implementations

Source

impl<'a> SessionLayoutBuilder<'a>

pub const fn window(self, window_index: u32) -> Self

Selects the window index that will receive the layout.

This layout API mutates one existing window. The target window must already exist and must contain exactly one pane when GridLayoutBuilder::apply is called.

pub const fn grid(self, columns: usize, rows: usize) -> GridLayoutBuilder<'a>

Starts a grid layout.

The first argument is the maximum number of columns per row, matching the grid example grid(3, 2) for “three panes on top, two panes below”. The second argument is the maximum number of rows.